package com.chinaitop.depot.intelligent.basicdata.model;

import java.util.Date;

public class TJctable {
    private String id;

    private String orgId;

    private String vJcName;

    private String vJcCode;

    private String vWsSrc;

    private String vVedioIp;

    private Integer iVedioPort;

    private String vVedioUser;

    private String vVedioPwd;

    private Integer vVedioTdh;

    private String vCfCode;

    private String vJcpp;

    private String updatePerson;

    private Date updateTime;

    private String dataSource;

    private String vRemark;

    private Integer delFlag;

    /**
     * 数量检测id 32位唯一值
     * @return id 数量检测id 32位唯一值
     */
    public String getId() {
        return id;
    }

    /**
     * 数量检测id 32位唯一值
     * @param id 数量检测id 32位唯一值
     */
    public void setId(String id) {
        this.id = id == null ? null : id.trim();
    }

    /**
     * 库房编码
     * @return org_id 库房编码
     */
    public String getOrgId() {
        return orgId;
    }

    /**
     * 库房编码
     * @param orgId 库房编码
     */
    public void setOrgId(String orgId) {
        this.orgId = orgId == null ? null : orgId.trim();
    }

    /**
     * 数量检测名称
     * @return v_jc_name 数量检测名称
     */
    public String getvJcName() {
        return vJcName;
    }

    /**
     * 数量检测名称
     * @param vJcName 数量检测名称
     */
    public void setvJcName(String vJcName) {
        this.vJcName = vJcName == null ? null : vJcName.trim();
    }

    /**
     * 数量检测编码
     * @return v_jc_code 数量检测编码
     */
    public String getvJcCode() {
        return vJcCode;
    }

    /**
     * 数量检测编码
     * @param vJcCode 数量检测编码
     */
    public void setvJcCode(String vJcCode) {
        this.vJcCode = vJcCode == null ? null : vJcCode.trim();
    }

    /**
     * 数量检测WS接口地址
     * @return v_ws_src 数量检测WS接口地址
     */
    public String getvWsSrc() {
        return vWsSrc;
    }

    /**
     * 数量检测WS接口地址
     * @param vWsSrc 数量检测WS接口地址
     */
    public void setvWsSrc(String vWsSrc) {
        this.vWsSrc = vWsSrc == null ? null : vWsSrc.trim();
    }

    /**
     * 视频IP
     * @return v_vedio_ip 视频IP
     */
    public String getvVedioIp() {
        return vVedioIp;
    }

    /**
     * 视频IP
     * @param vVedioIp 视频IP
     */
    public void setvVedioIp(String vVedioIp) {
        this.vVedioIp = vVedioIp == null ? null : vVedioIp.trim();
    }

    /**
     * 视频端口
     * @return i_vedio_port 视频端口
     */
    public Integer getiVedioPort() {
        return iVedioPort;
    }

    /**
     * 视频端口
     * @param iVedioPort 视频端口
     */
    public void setiVedioPort(Integer iVedioPort) {
        this.iVedioPort = iVedioPort;
    }

    /**
     * 视频用户名
     * @return v_vedio_user 视频用户名
     */
    public String getvVedioUser() {
        return vVedioUser;
    }

    /**
     * 视频用户名
     * @param vVedioUser 视频用户名
     */
    public void setvVedioUser(String vVedioUser) {
        this.vVedioUser = vVedioUser == null ? null : vVedioUser.trim();
    }

    /**
     * 视频密码
     * @return v_vedio_pwd 视频密码
     */
    public String getvVedioPwd() {
        return vVedioPwd;
    }

    /**
     * 视频密码
     * @param vVedioPwd 视频密码
     */
    public void setvVedioPwd(String vVedioPwd) {
        this.vVedioPwd = vVedioPwd == null ? null : vVedioPwd.trim();
    }

    /**
     * 视频通道号
     * @return v_vedio_tdh 视频通道号
     */
    public Integer getvVedioTdh() {
        return vVedioTdh;
    }

    /**
     * 视频通道号
     * @param vVedioTdh 视频通道号
     */
    public void setvVedioTdh(Integer vVedioTdh) {
        this.vVedioTdh = vVedioTdh;
    }

    /**
     * 仓房编码
     * @return v_cf_code 仓房编码
     */
    public String getvCfCode() {
        return vCfCode;
    }

    /**
     * 仓房编码
     * @param vCfCode 仓房编码
     */
    public void setvCfCode(String vCfCode) {
        this.vCfCode = vCfCode == null ? null : vCfCode.trim();
    }

    /**
     * 设备品牌
     * @return v_jcpp 设备品牌
     */
    public String getvJcpp() {
        return vJcpp;
    }

    /**
     * 设备品牌
     * @param vJcpp 设备品牌
     */
    public void setvJcpp(String vJcpp) {
        this.vJcpp = vJcpp == null ? null : vJcpp.trim();
    }

    /**
     * 创建人
     * @return update_person 创建人
     */
    public String getUpdatePerson() {
        return updatePerson;
    }

    /**
     * 创建人
     * @param updatePerson 创建人
     */
    public void setUpdatePerson(String updatePerson) {
        this.updatePerson = updatePerson == null ? null : updatePerson.trim();
    }

    /**
     * 创建时间
     * @return update_time 创建时间
     */
    public Date getUpdateTime() {
        return updateTime;
    }

    /**
     * 创建时间
     * @param updateTime 创建时间
     */
    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    /**
     * 数据来源
     * @return data_source 数据来源
     */
    public String getDataSource() {
        return dataSource;
    }

    /**
     * 数据来源
     * @param dataSource 数据来源
     */
    public void setDataSource(String dataSource) {
        this.dataSource = dataSource == null ? null : dataSource.trim();
    }

    /**
     * 描述信息
     * @return v_remark 描述信息
     */
    public String getvRemark() {
        return vRemark;
    }

    /**
     * 描述信息
     * @param vRemark 描述信息
     */
    public void setvRemark(String vRemark) {
        this.vRemark = vRemark == null ? null : vRemark.trim();
    }

    /**
     * 删除标志（0：删除，1：未删除）
     * @return del_flag 删除标志（0：删除，1：未删除）
     */
    public Integer getDelFlag() {
        return delFlag;
    }

    /**
     * 删除标志（0：删除，1：未删除）
     * @param delFlag 删除标志（0：删除，1：未删除）
     */
    public void setDelFlag(Integer delFlag) {
        this.delFlag = delFlag;
    }
}